@@ -6,7 +6,7 @@ import (
 
 	"github.com/spf13/cobra"
 
-	"github.com/lxc/incus/v6/client"
+	incus "github.com/lxc/incus/v6/client"
 	cli "github.com/lxc/incus/v6/internal/cmd"
 	"github.com/lxc/incus/v6/internal/i18n"
 	"github.com/lxc/incus/v6/internal/instance"
@@ -17,19 +17,20 @@ import (
 type cmdCopy struct {
 	global *cmdGlobal
 
-	flagNoProfiles        bool
-	flagProfile           []string
-	flagConfig            []string
-	flagDevice            []string
-	flagEphemeral         bool
-	flagInstanceOnly      bool
-	flagMode              string
-	flagStateless         bool
-	flagStorage           string
-	flagTarget            string
-	flagTargetProject     string
-	flagRefresh           bool
-	flagAllowInconsistent bool
+	flagNoProfiles          bool
+	flagProfile             []string
+	flagConfig              []string
+	flagDevice              []string
+	flagEphemeral           bool
+	flagInstanceOnly        bool
+	flagMode                string
+	flagStateless           bool
+	flagStorage             string
+	flagTarget              string
+	flagTargetProject       string
+	flagRefresh             bool
+	flagRefreshExcludeOlder bool
+	flagAllowInconsistent   bool
 }
 
 func (c *cmdCopy) Command() *cobra.Command {
@@ -61,6 +62,7 @@ The pull transfer mode is the default as it is compatible with all server versio
 	cmd.Flags().StringVar(&c.flagTargetProject, "target-project", "", i18n.G("Copy to a project different from the source")+"``")
 	cmd.Flags().BoolVar(&c.flagNoProfiles, "no-profiles", false, i18n.G("Create the instance with no profiles applied"))
 	cmd.Flags().BoolVar(&c.flagRefresh, "refresh", false, i18n.G("Perform an incremental copy"))
+	cmd.Flags().BoolVar(&c.flagRefreshExcludeOlder, "refresh-exclude-older", false, i18n.G("During incremental copy, exclude source snapshots earlier than latest target snapshot"))
 	cmd.Flags().BoolVar(&c.flagAllowInconsistent, "allow-inconsistent", false, i18n.G("Ignore copy errors for volatile files"))
 
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
@@ -69,7 +71,7 @@ The pull transfer mode is the default as it is compatible with all server versio
 		}
 
 		if len(args) == 1 {
-			return c.global.cmpRemotes(false)
+			return c.global.cmpRemotes(toComplete, false)
 		}
 
 		return nil, cobra.ShellCompDirectiveNoFileComp
@@ -256,12 +258,13 @@ func (c *cmdCopy) copyInstance(conf *config.Config, sourceResource string, destR
 	} else {
 		// Prepare the instance creation request
 		args := incus.InstanceCopyArgs{
-			Name:              destName,
-			Live:              stateful,
-			InstanceOnly:      instanceOnly,
-			Mode:              mode,
-			Refresh:           c.flagRefresh,
-			AllowInconsistent: c.flagAllowInconsistent,
+			Name:                destName,
+			Live:                stateful,
+			InstanceOnly:        instanceOnly,
+			Mode:                mode,
+			Refresh:             c.flagRefresh,
+			RefreshExcludeOlder: c.flagRefreshExcludeOlder,
+			AllowInconsistent:   c.flagAllowInconsistent,
 		}
 
 		// Copy of an instance into a new instance
