@@ -6,24 +6,25 @@ import (
 	"os"
 	"os/user"
 	"path"
-	"path/filepath"
 	"slices"
 
+	"github.com/kballard/go-shellquote"
 	"github.com/spf13/cobra"
 
-	"github.com/lxc/incus/v6/client"
+	incus "github.com/lxc/incus/v6/client"
 	cli "github.com/lxc/incus/v6/internal/cmd"
 	"github.com/lxc/incus/v6/internal/i18n"
 	internalUtil "github.com/lxc/incus/v6/internal/util"
 	"github.com/lxc/incus/v6/internal/version"
 	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/ask"
 	config "github.com/lxc/incus/v6/shared/cliconfig"
 	"github.com/lxc/incus/v6/shared/logger"
 	"github.com/lxc/incus/v6/shared/util"
 )
 
 type cmdGlobal struct {
-	asker cli.Asker
+	asker ask.Asker
 
 	conf     *config.Config
 	confPath string
@@ -70,14 +71,28 @@ Use "{{.CommandPath}} [command] --help" for more information about a command.{{e
 `
 }
 
-func main() {
-	// Process aliases
-	err := execIfAliases()
+func aliases() []string {
+	c, err := config.LoadConfig("")
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "Error: %v\n", err)
-		os.Exit(1)
+		return nil
 	}
 
+	aliases := make([]string, 0, len(defaultAliases)+len(c.Aliases))
+
+	// Add default aliases
+	for alias := range defaultAliases {
+		aliases = append(aliases, alias)
+	}
+
+	// Add user-defined aliases
+	for alias := range c.Aliases {
+		aliases = append(aliases, alias)
+	}
+
+	return aliases
+}
+
+func createApp() (*cobra.Command, *cmdGlobal) {
 	// Setup the parser
 	app := &cobra.Command{}
 	app.Use = "incus"
@@ -92,9 +107,10 @@ Custom commands can be defined through aliases, use "incus alias" to control tho
 	app.SilenceUsage = true
 	app.SilenceErrors = true
 	app.CompletionOptions = cobra.CompletionOptions{HiddenDefaultCmd: true}
+	app.ValidArgs = aliases()
 
 	// Global flags
-	globalCmd := cmdGlobal{cmd: app, asker: cli.NewAsker(bufio.NewReader(os.Stdin))}
+	globalCmd := cmdGlobal{cmd: app, asker: ask.NewAsker(bufio.NewReader(os.Stdin))}
 
 	app.PersistentFlags().BoolVar(&globalCmd.flagVersion, "version", false, i18n.G("Print version number"))
 	app.PersistentFlags().BoolVarP(&globalCmd.flagHelp, "help", "h", false, i18n.G("Print help"))
@@ -265,6 +281,10 @@ Custom commands can be defined through aliases, use "incus alias" to control tho
 	warningCmd := cmdWarning{global: &globalCmd}
 	app.AddCommand(warningCmd.Command())
 
+	// webui sub-command
+	webuiCmd := cmdWebui{global: &globalCmd}
+	app.AddCommand(webuiCmd.Command())
+
 	// Get help command
 	app.InitDefaultHelpCmd()
 	var help *cobra.Command
@@ -279,8 +299,14 @@ Custom commands can be defined through aliases, use "incus alias" to control tho
 	app.Flags().BoolVar(&globalCmd.flagHelpAll, "all", false, i18n.G("Show less common commands"))
 	help.Flags().BoolVar(&globalCmd.flagHelpAll, "all", false, i18n.G("Show less common commands"))
 
-	// Deal with --all flag and --sub-commands flag
-	err = app.ParseFlags(os.Args[1:])
+	return app, &globalCmd
+}
+
+func main() {
+	app, globalCmd := createApp()
+
+	// Deal with --all and --sub-commands flags as well as process aliases.
+	err := app.ParseFlags(os.Args[1:])
 	if err == nil {
 		if globalCmd.flagHelpAll {
 			// Show all commands
@@ -298,6 +324,13 @@ Custom commands can be defined through aliases, use "incus alias" to control tho
 		}
 	}
 
+	// Process aliases
+	err = execIfAliases(app)
+	if err != nil {
+		fmt.Fprintf(os.Stderr, "Error: %v\n", err)
+		os.Exit(1)
+	}
+
 	// Run the main command and handle errors
 	err = app.Execute()
 	if err != nil {
@@ -311,7 +344,11 @@ If you already added a remote server, make it the default with "incus remote swi
 		}
 
 		// Default error handling
-		fmt.Fprintf(os.Stderr, "Error: %v\n", err)
+		if os.Getenv("INCUS_ALIASES") == "1" {
+			fmt.Fprintf(os.Stderr, i18n.G("Error while executing alias expansion: %s\n"), shellquote.Join(os.Args...))
+		}
+
+		fmt.Fprintf(os.Stderr, i18n.G("Error: %v\n"), err)
 
 		// If custom exit status not set, use default error status.
 		if globalCmd.ret == 0 {
@@ -332,23 +369,6 @@ func (c *cmdGlobal) PreRun(cmd *cobra.Command, args []string) error {
 		return nil
 	}
 
-	// Figure out the config directory and config path
-	var configDir string
-	if os.Getenv("INCUS_CONF") != "" {
-		configDir = os.Getenv("INCUS_CONF")
-	} else if os.Getenv("HOME") != "" && util.PathExists(os.Getenv("HOME")) {
-		configDir = path.Join(os.Getenv("HOME"), ".config", "incus")
-	} else {
-		user, err := user.Current()
-		if err != nil {
-			return err
-		}
-
-		if util.PathExists(user.HomeDir) {
-			configDir = path.Join(user.HomeDir, ".config", "incus")
-		}
-	}
-
 	// Figure out a potential cache path.
 	var cachePath string
 	if os.Getenv("INCUS_CACHE") != "" {
@@ -373,24 +393,17 @@ func (c *cmdGlobal) PreRun(cmd *cobra.Command, args []string) error {
 		}
 	}
 
-	// If no homedir could be found, treat as if --force-local was passed.
-	if configDir == "" {
+	c.conf, err = config.LoadConfig("")
+	if err != nil {
+		return fmt.Errorf(i18n.G("Failed to load configuration: %s"), err)
+	}
+
+	// If no config dir could be found, treat as if --force-local was passed.
+	if c.conf.ConfigDir == "" {
 		c.flagForceLocal = true
 	}
 
-	c.confPath = os.ExpandEnv(path.Join(configDir, "config.yml"))
-
-	// Load the configuration
-	if c.flagForceLocal {
-		c.conf = config.NewConfig("", true)
-	} else if util.PathExists(c.confPath) {
-		c.conf, err = config.LoadConfig(c.confPath)
-		if err != nil {
-			return err
-		}
-	} else {
-		c.conf = config.NewConfig(filepath.Dir(c.confPath), true)
-	}
+	c.confPath = c.conf.ConfigPath("config.yml")
 
 	// Set cache directory in config.
 	c.conf.CacheDir = cachePath
@@ -404,7 +417,7 @@ func (c *cmdGlobal) PreRun(cmd *cobra.Command, args []string) error {
 
 	// Setup password helper
 	c.conf.PromptPassword = func(filename string) (string, error) {
-		return cli.AskPasswordOnce(fmt.Sprintf(i18n.G("Password for %s: "), filename)), nil
+		return c.asker.AskPasswordOnce(fmt.Sprintf(i18n.G("Password for %s: "), filename)), nil
 	}
 
 	// If the user is running a command that may attempt to connect to the local daemon
