@@ -232,7 +232,7 @@ func (c *cmdNetworkForwardList) Run(cmd *cobra.Command, args []string) error {
 		header = append(header, column.Name)
 	}
 
-	return cli.RenderTable(c.flagFormat, header, data, forwards)
+	return cli.RenderTable(os.Stdout, c.flagFormat, header, data, forwards)
 }
 
 // Show.
