@@ -3,11 +3,11 @@ package main
 import (
 	"context"
 
-	clusterConfig "github.com/lxc/incus/internal/server/cluster/config"
-	"github.com/lxc/incus/internal/server/db"
-	"github.com/lxc/incus/internal/server/node"
-	"github.com/lxc/incus/internal/server/state"
-	"github.com/lxc/incus/shared/proxy"
+	clusterConfig "github.com/lxc/incus/v6/internal/server/cluster/config"
+	"github.com/lxc/incus/v6/internal/server/db"
+	"github.com/lxc/incus/v6/internal/server/node"
+	"github.com/lxc/incus/v6/internal/server/state"
+	"github.com/lxc/incus/v6/shared/proxy"
 )
 
 func daemonConfigRender(state *state.State) (map[string]string, error) {
