@@ -1,37 +1,5 @@
 package main
 
-/*
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE 1
-#endif
-#include <stdio.h>
-#include <linux/hidraw.h>
-
-#include "../../shared/cgo/memory_utils.h"
-
-#ifndef HIDIOCGRAWINFO
-#define HIDIOCGRAWINFO _IOR('H', 0x03, struct hidraw_devinfo)
-struct hidraw_devinfo {
-	__u32 bustype;
-	__s16 vendor;
-	__s16 product;
-};
-#endif
-
-static int get_hidraw_devinfo(int fd, struct hidraw_devinfo *info)
-{
-	int ret;
-
-	ret = ioctl(fd, HIDIOCGRAWINFO, info);
-	if (ret)
-		return -1;
-
-	return 0;
-}
-
-*/
-import "C"
-
 import (
 	"fmt"
 	"os"
@@ -41,18 +9,19 @@ import (
 	"sort"
 	"strconv"
 	"strings"
+	"unsafe"
 
 	"golang.org/x/sys/unix"
 
-	"github.com/lxc/incus/internal/server/cgroup"
-	"github.com/lxc/incus/internal/server/device"
-	"github.com/lxc/incus/internal/server/instance"
-	"github.com/lxc/incus/internal/server/instance/instancetype"
-	"github.com/lxc/incus/internal/server/resources"
-	"github.com/lxc/incus/internal/server/state"
-	_ "github.com/lxc/incus/shared/cgo" // Used by cgo
-	"github.com/lxc/incus/shared/logger"
-	"github.com/lxc/incus/shared/util"
+	"github.com/lxc/incus/v6/internal/linux"
+	"github.com/lxc/incus/v6/internal/server/cgroup"
+	"github.com/lxc/incus/v6/internal/server/device"
+	"github.com/lxc/incus/v6/internal/server/instance"
+	"github.com/lxc/incus/v6/internal/server/instance/instancetype"
+	"github.com/lxc/incus/v6/internal/server/resources"
+	"github.com/lxc/incus/v6/internal/server/state"
+	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/util"
 )
 
 type deviceTaskCPU struct {
@@ -709,10 +678,16 @@ func devicesRegister(instances []instance.Instance) {
 }
 
 func getHidrawDevInfo(fd int) (string, string, error) {
-	info := C.struct_hidraw_devinfo{}
-	ret, err := C.get_hidraw_devinfo(C.int(fd), &info)
-	if ret != 0 {
-		return "", "", err
+	type hidInfo struct {
+		busType uint32
+		vendor  int16
+		product int16
+	}
+
+	var info hidInfo
+	_, _, errno := unix.Syscall(unix.SYS_IOCTL, uintptr(fd), linux.IoctlHIDIOCGrawInfo, uintptr(unsafe.Pointer(&info)))
+	if errno != 0 {
+		return "", "", fmt.Errorf("Failed setting received UUID: %w", unix.Errno(errno))
 	}
 
 	return fmt.Sprintf("%04x", info.vendor), fmt.Sprintf("%04x", info.product), nil
