@@ -10,14 +10,17 @@ import (
 
 	"github.com/gorilla/mux"
 
-	"github.com/lxc/incus/v6/client"
+	incus "github.com/lxc/incus/v6/client"
 	internalInstance "github.com/lxc/incus/v6/internal/instance"
 	"github.com/lxc/incus/v6/internal/server/auth"
 	"github.com/lxc/incus/v6/internal/server/cluster"
+	clusterRequest "github.com/lxc/incus/v6/internal/server/cluster/request"
 	"github.com/lxc/incus/v6/internal/server/db"
 	dbCluster "github.com/lxc/incus/v6/internal/server/db/cluster"
 	"github.com/lxc/incus/v6/internal/server/db/operationtype"
+	deviceConfig "github.com/lxc/incus/v6/internal/server/device/config"
 	"github.com/lxc/incus/v6/internal/server/instance"
+	"github.com/lxc/incus/v6/internal/server/instance/instancetype"
 	"github.com/lxc/incus/v6/internal/server/operations"
 	"github.com/lxc/incus/v6/internal/server/project"
 	"github.com/lxc/incus/v6/internal/server/request"
@@ -233,9 +236,15 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 				return response.BadRequest(fmt.Errorf("Instance must be stopped to be moved statelessly"))
 			}
 
-			// Storage pool changes require a stopped instance.
+			// Storage pool changes require a target flag.
 			if req.Pool != "" {
-				return response.BadRequest(fmt.Errorf("Instance must be stopped to be moved across storage pools"))
+				if inst.Type() != instancetype.VM {
+					return response.BadRequest(fmt.Errorf("Storage pool change supported only by virtual-machines"))
+				}
+
+				if target == "" {
+					return response.BadRequest(fmt.Errorf("Storage pool can be specified only together with target flag"))
+				}
 			}
 
 			// Project changes require a stopped instance.
@@ -315,29 +324,103 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 			return response.SmartError(err)
 		}
 
-		// If no specific server and a placement scriplet exists, call it with the candidates.
-		if targetMemberInfo == nil && s.GlobalConfig.InstancesPlacementScriptlet() != "" {
+		// Run instance placement scriptlet if enabled.
+		if s.GlobalConfig.InstancesPlacementScriptlet() != "" {
+			// If a target was specified, limit the list of candidates to that target.
+			if targetMemberInfo != nil {
+				targetCandidates = []db.NodeInfo{*targetMemberInfo}
+			}
+
 			leaderAddress, err := s.Cluster.LeaderAddress()
 			if err != nil {
 				return response.InternalError(err)
 			}
 
+			// Load profiles.
+			profileNames := make([]string, 0, len(inst.Profiles()))
+			for _, profile := range inst.Profiles() {
+				profileNames = append(profileNames, profile.Name)
+			}
+
+			profiles := make([]api.Profile, 0, len(profileNames))
+			if len(profileNames) > 0 {
+				err = s.DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
+					profileFilters := make([]dbCluster.ProfileFilter, 0, len(profileNames))
+					for _, profileName := range profileNames {
+						profileFilters = append(profileFilters, dbCluster.ProfileFilter{
+							Project: &instProject,
+							Name:    &profileName,
+						})
+					}
+
+					dbProfiles, err := dbCluster.GetProfiles(ctx, tx.Tx(), profileFilters...)
+					if err != nil {
+						return err
+					}
+
+					dbProfileConfigs, err := dbCluster.GetConfig(ctx, tx.Tx(), "profile")
+					if err != nil {
+						return err
+					}
+
+					dbProfileDevices, err := dbCluster.GetDevices(ctx, tx.Tx(), "profile")
+					if err != nil {
+						return err
+					}
+
+					profilesByName := make(map[string]dbCluster.Profile, len(dbProfiles))
+					for _, dbProfile := range dbProfiles {
+						profilesByName[dbProfile.Name] = dbProfile
+					}
+
+					for _, profileName := range profileNames {
+						profile, found := profilesByName[profileName]
+						if !found {
+							return fmt.Errorf("Requested profile %q doesn't exist", profileName)
+						}
+
+						apiProfile, err := profile.ToAPI(ctx, tx.Tx(), dbProfileConfigs, dbProfileDevices)
+						if err != nil {
+							return err
+						}
+
+						profiles = append(profiles, *apiProfile)
+					}
+
+					return nil
+				})
+				if err != nil {
+					return response.SmartError(err)
+				}
+			}
+
+			// Prepare the placement scriptlet context.
 			req := apiScriptlet.InstancePlacement{
 				InstancesPost: api.InstancesPost{
 					Name: name,
 					Type: api.InstanceType(instanceType.String()),
 					InstancePut: api.InstancePut{
-						Config:  inst.ExpandedConfig(),
-						Devices: inst.ExpandedDevices().CloneNative(),
+						Config:   db.ExpandInstanceConfig(inst.LocalConfig(), profiles),
+						Devices:  db.ExpandInstanceDevices(deviceConfig.NewDevices(inst.LocalDevices().CloneNative()), profiles).CloneNative(),
+						Profiles: profileNames,
 					},
 				},
-				Project: projectName,
+				Project: instProject,
 				Reason:  apiScriptlet.InstancePlacementReasonRelocation,
 			}
 
-			targetMemberInfo, err = scriptlet.InstancePlacementRun(r.Context(), logger.Log, s, &req, targetCandidates, leaderAddress)
-			if err != nil {
-				return response.BadRequest(fmt.Errorf("Failed instance placement scriptlet: %w", err))
+			if targetMemberInfo == nil {
+				// Get a new target.
+				targetMemberInfo, err = scriptlet.InstancePlacementRun(r.Context(), logger.Log, s, &req, targetCandidates, leaderAddress)
+				if err != nil {
+					return response.BadRequest(fmt.Errorf("Failed instance placement scriptlet: %w", err))
+				}
+			} else {
+				// Validate the current target.
+				_, err = scriptlet.InstancePlacementRun(r.Context(), logger.Log, s, &req, targetCandidates, leaderAddress)
+				if err != nil {
+					return response.BadRequest(fmt.Errorf("Failed instance placement scriptlet: %w", err))
+				}
 			}
 		}
 
@@ -353,13 +436,11 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 				}
 			}
 
-			err := s.DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
-				targetMemberInfo, err = tx.GetNodeWithLeastInstances(ctx, filteredCandidateMembers)
-				return err
-			})
-			if err != nil {
-				return response.SmartError(err)
+			if len(filteredCandidateMembers) == 0 {
+				return response.InternalError(fmt.Errorf("Couldn't find a cluster member for the instance"))
 			}
+
+			targetMemberInfo = &filteredCandidateMembers[0]
 		}
 
 		if targetMemberInfo.IsOffline(s.GlobalConfig.OfflineThreshold()) {
@@ -420,7 +501,7 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 	}
 
 	// Cross-server instance migration.
-	ws, err := newMigrationSource(inst, req.Live, req.InstanceOnly, req.AllowInconsistent, "", req.Target)
+	ws, err := newMigrationSource(inst, req.Live, req.InstanceOnly, req.AllowInconsistent, "", "", req.Target)
 	if err != nil {
 		return response.InternalError(err)
 	}
@@ -463,6 +544,11 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 		return fmt.Errorf("Failed loading instance storage pool: %w", err)
 	}
 
+	// Check that we're not requested to move to the same storage pool we're currently use.
+	if req.Pool != "" && req.Pool == sourcePool.Name() {
+		return fmt.Errorf("Requested storage pool is the same as current pool")
+	}
+
 	// Get the DB volume type for the instance.
 	volType, err := storagePools.InstanceTypeToVolumeType(inst.Type())
 	if err != nil {
@@ -580,10 +666,15 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 		req.Name = ""
 	}
 
-	// Handle pool and project moves.
-	if req.Project != "" || req.Pool != "" {
+	// Handle pool and project moves for stopped instances.
+	if (req.Project != "" || req.Pool != "") && !req.Live {
 		// Get a local client.
-		target, err := incus.ConnectIncusUnix(s.OS.GetUnixSocket(), nil)
+		args := &incus.ConnectionArgs{
+			SkipGetServer: true,
+			UserAgent:     clusterRequest.UserAgentClient,
+		}
+
+		target, err := incus.ConnectIncusUnix(s.OS.GetUnixSocket(), args)
 		if err != nil {
 			return err
 		}
@@ -622,13 +713,18 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 					return err
 				}
 
+				profileConfigs, err := dbCluster.GetConfig(ctx, tx.Tx(), "profile")
+				if err != nil {
+					return err
+				}
+
 				profileDevices, err := dbCluster.GetDevices(ctx, tx.Tx(), "profile")
 				if err != nil {
 					return err
 				}
 
 				for _, profile := range rawProfiles {
-					apiProfile, err := profile.ToAPI(ctx, tx.Tx(), profileDevices)
+					apiProfile, err := profile.ToAPI(ctx, tx.Tx(), profileConfigs, profileDevices)
 					if err != nil {
 						return err
 					}
@@ -733,7 +829,7 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 		req.Project = ""
 	}
 
-	// Handle remote migrations (location changes).
+	// Handle remote migrations (location and storage pool changes).
 	if targetMemberInfo != nil && inst.Location() != targetMemberInfo.Name {
 		// Get the client.
 		networkCert := s.Endpoints.NetworkCert()
@@ -771,7 +867,7 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 		}
 
 		// Setup a new migration source.
-		sourceMigration, err := newMigrationSource(inst, req.Live, false, req.AllowInconsistent, inst.Name(), nil)
+		sourceMigration, err := newMigrationSource(inst, req.Live, false, req.AllowInconsistent, inst.Name(), req.Pool, nil)
 		if err != nil {
 			return fmt.Errorf("Failed setting up instance migration on source: %w", err)
 		}
@@ -895,8 +991,9 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 			return err
 		}
 
-		// Cleanup instance paths on source member if using remote shared storage.
-		if sourcePool.Driver().Info().Remote {
+		// Cleanup instance paths on source member if using remote shared storage
+		// and there was no storage pool change.
+		if sourcePool.Driver().Info().Remote && req.Pool == "" {
 			err = sourcePool.CleanupInstancePaths(inst, nil)
 			if err != nil {
 				return fmt.Errorf("Failed cleaning up instance paths on source member: %w", err)
