@@ -31,7 +31,7 @@ func (suite *containerTestSuite) TestContainer_ProfilesDefault() {
 		Name:      "testFoo",
 	}
 
-	c, op, _, err := instance.CreateInternal(suite.d.State(), args, true, true)
+	c, op, _, err := instance.CreateInternal(suite.d.State(), args, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	defer func() { _ = c.Delete(true) }()
@@ -93,7 +93,7 @@ func (suite *containerTestSuite) TestContainer_ProfilesMulti() {
 		Name:      "testFoo",
 	}
 
-	c, op, _, err := instance.CreateInternal(suite.d.State(), args, true, true)
+	c, op, _, err := instance.CreateInternal(suite.d.State(), args, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	defer func() { _ = c.Delete(true) }()
@@ -129,7 +129,7 @@ func (suite *containerTestSuite) TestContainer_ProfilesOverwriteDefaultNic() {
 	})
 	suite.Req.Nil(err)
 
-	c, op, _, err := instance.CreateInternal(suite.d.State(), args, true, true)
+	c, op, _, err := instance.CreateInternal(suite.d.State(), args, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	suite.True(c.IsPrivileged(), "This container should be privileged.")
@@ -169,7 +169,7 @@ func (suite *containerTestSuite) TestContainer_LoadFromDB() {
 	suite.Req.Nil(err)
 
 	// Create the container
-	c, op, _, err := instance.CreateInternal(suite.d.State(), args, true, true)
+	c, op, _, err := instance.CreateInternal(suite.d.State(), args, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	defer func() { _ = c.Delete(true) }()
@@ -216,7 +216,7 @@ func (suite *containerTestSuite) TestContainer_Path_Regular() {
 		Name:      "testFoo",
 	}
 
-	c, op, _, err := instance.CreateInternal(suite.d.State(), args, true, true)
+	c, op, _, err := instance.CreateInternal(suite.d.State(), args, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	defer func() { _ = c.Delete(true) }()
@@ -233,7 +233,7 @@ func (suite *containerTestSuite) TestContainer_LogPath() {
 		Name:      "testFoo",
 	}
 
-	c, op, _, err := instance.CreateInternal(suite.d.State(), args, true, true)
+	c, op, _, err := instance.CreateInternal(suite.d.State(), args, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	defer func() { _ = c.Delete(true) }()
@@ -249,7 +249,7 @@ func (suite *containerTestSuite) TestContainer_IsPrivileged_Privileged() {
 		Name:      "testFoo",
 	}
 
-	c, op, _, err := instance.CreateInternal(suite.d.State(), args, true, true)
+	c, op, _, err := instance.CreateInternal(suite.d.State(), args, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	suite.Req.True(c.IsPrivileged(), "This container should be privileged.")
@@ -283,7 +283,7 @@ func (suite *containerTestSuite) TestContainer_AddRoutedNicValidation() {
 		Name: "testFoo",
 	}
 
-	c, op, _, err := instance.CreateInternal(suite.d.State(), args, true, true)
+	c, op, _, err := instance.CreateInternal(suite.d.State(), args, nil, true, true)
 	suite.Req.NoError(err)
 	op.Done(nil)
 	err = c.Update(db.InstanceArgs{
@@ -335,7 +335,7 @@ func (suite *containerTestSuite) TestContainer_IsPrivileged_Unprivileged() {
 		Name:      "testFoo",
 	}
 
-	c, op, _, err := instance.CreateInternal(suite.d.State(), args, true, true)
+	c, op, _, err := instance.CreateInternal(suite.d.State(), args, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	suite.Req.False(c.IsPrivileged(), "This container should be unprivileged.")
@@ -349,7 +349,7 @@ func (suite *containerTestSuite) TestContainer_Rename() {
 		Name:      "testFoo",
 	}
 
-	c, op, _, err := instance.CreateInternal(suite.d.State(), args, true, true)
+	c, op, _, err := instance.CreateInternal(suite.d.State(), args, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	defer func() { _ = c.Delete(true) }()
@@ -365,7 +365,7 @@ func (suite *containerTestSuite) TestContainer_findIdmap_isolated() {
 		Config: map[string]string{
 			"security.idmap.isolated": "true",
 		},
-	}, true, true)
+	}, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	defer func() { _ = c1.Delete(true) }()
@@ -376,7 +376,7 @@ func (suite *containerTestSuite) TestContainer_findIdmap_isolated() {
 		Config: map[string]string{
 			"security.idmap.isolated": "true",
 		},
-	}, true, true)
+	}, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	defer func() { _ = c2.Delete(true) }()
@@ -408,7 +408,7 @@ func (suite *containerTestSuite) TestContainer_findIdmap_mixed() {
 		Config: map[string]string{
 			"security.idmap.isolated": "false",
 		},
-	}, true, true)
+	}, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	defer func() { _ = c1.Delete(true) }()
@@ -419,7 +419,7 @@ func (suite *containerTestSuite) TestContainer_findIdmap_mixed() {
 		Config: map[string]string{
 			"security.idmap.isolated": "true",
 		},
-	}, true, true)
+	}, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	defer func() { _ = c2.Delete(true) }()
@@ -452,7 +452,7 @@ func (suite *containerTestSuite) TestContainer_findIdmap_raw() {
 			"security.idmap.isolated": "false",
 			"raw.idmap":               "both 1000 1000",
 		},
-	}, true, true)
+	}, nil, true, true)
 	suite.Req.Nil(err)
 	op.Done(nil)
 	defer func() { _ = c1.Delete(true) }()
@@ -489,7 +489,7 @@ func (suite *containerTestSuite) TestContainer_findIdmap_maxed() {
 			Config: map[string]string{
 				"security.idmap.isolated": "true",
 			},
-		}, true, true)
+		}, nil, true, true)
 
 		/* we should fail if there are no ids left */
 		if i != 6 {
