@@ -11,7 +11,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/lxc/incus/v6/internal/revert"
 	"github.com/lxc/incus/v6/internal/server/backup"
 	"github.com/lxc/incus/v6/internal/server/certificate"
 	"github.com/lxc/incus/v6/internal/server/cluster"
@@ -28,6 +27,7 @@ import (
 	internalUtil "github.com/lxc/incus/v6/internal/util"
 	"github.com/lxc/incus/v6/shared/api"
 	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/revert"
 	"github.com/lxc/incus/v6/shared/subprocess"
 	"github.com/lxc/incus/v6/shared/util"
 )
@@ -85,6 +85,7 @@ var patches = []patch{
 	{name: "storage_zfs_unset_invalid_block_settings_v2", stage: patchPostDaemonStorage, run: patchStorageZfsUnsetInvalidBlockSettingsV2},
 	{name: "runtime_directory", stage: patchPostDaemonStorage, run: patchRuntimeDirectory},
 	{name: "lvm_node_force_reuse", stage: patchPostDaemonStorage, run: patchLvmForceReuseKey},
+	{name: "auth_openfga_viewer", stage: patchPostNetworks, run: patchGenericAuthorization},
 }
 
 type patch struct {
@@ -135,6 +136,10 @@ func patchesApply(d *Daemon, stage patchStage) error {
 			return fmt.Errorf("Patch %q has no stage set: %d", patch.name, patch.stage)
 		}
 
+		if patch.stage != stage {
+			continue
+		}
+
 		if slices.Contains(appliedPatches, patch.name) {
 			continue
 		}
@@ -680,6 +685,10 @@ func patchMoveBackupsInstances(name string, d *Daemon) error {
 	return nil
 }
 
+func patchGenericAuthorization(name string, d *Daemon) error {
+	return d.authorizer.ApplyPatch(d.shutdownCtx, name)
+}
+
 func patchGenericStorage(name string, d *Daemon) error {
 	return storagePools.Patch(d.State(), name)
 }
