@@ -80,8 +80,9 @@ func LocalCopy(source string, dest string, bwlimit string, xattrs bool, rsyncArg
 		"--sparse",
 		"--devices",
 		"--delete",
-		"--checksum",
 		"--numeric-ids",
+		// Checks for file modifications on nanoseconds granularity.
+		"--modify-window=-1",
 	}
 
 	if xattrs {
@@ -318,6 +319,9 @@ func Recv(path string, conn io.ReadWriteCloser, tracker *ioprogress.ProgressTrac
 		"--devices",
 		"--partial",
 		"--sparse",
+		// This flag is only required on the receiving end.
+		// Checks for file modifications on nanoseconds granularity.
+		"--modify-window=-1",
 	}
 
 	if len(features) > 0 {
