@@ -28,12 +28,17 @@ profile "{{ .name }}" flags=(attach_disconnected,mediate_deleted) {
   # Network access
   network inet raw,
   network inet6 raw,
+  network unix stream,
+  network unix dgram,
 
   # Network-specific paths
   {{ .varPath }}/networks/{{ .networkName }}/dnsmasq.hosts/{,*} r,
   {{ .varPath }}/networks/{{ .networkName }}/dnsmasq.leases rw,
   {{ .varPath }}/networks/{{ .networkName }}/dnsmasq.raw r,
 
+  # Allow to restart dnsmasq
+  signal (receive) set=("hup","kill"),
+
   # Logging path
   {{ .logPath }}/dnsmasq.{{ .networkName }}.log rw,
 
