@@ -125,6 +125,27 @@ func (c *Config) MaxStandBy() int64 {
 	return c.m.GetInt64("cluster.max_standby")
 }
 
+// ClusterRebalanceBatch returns maximum number of instances to move during one re-balancing run.
+func (c *Config) ClusterRebalanceBatch() int64 {
+	return c.m.GetInt64("cluster.rebalance.batch")
+}
+
+// ClusterRebalanceCooldown returns amount of time during which an instance will not be moved again.
+func (c *Config) ClusterRebalanceCooldown() string {
+	return c.m.GetString("cluster.rebalance.cooldown")
+}
+
+// ClusterRebalanceInterval returns the interval at which to evaluate re-balanicng.
+func (c *Config) ClusterRebalanceInterval() int64 {
+	return c.m.GetInt64("cluster.rebalance.interval")
+}
+
+// ClusterRebalanceThreshold returns load difference between most and least busy server
+// needed to trigger a migration.
+func (c *Config) ClusterRebalanceThreshold() int64 {
+	return c.m.GetInt64("cluster.rebalance.threshold")
+}
+
 // NetworkOVNIntegrationBridge returns the integration OVS bridge to use for OVN networks.
 func (c *Config) NetworkOVNIntegrationBridge() string {
 	return c.m.GetString("network.ovn.integration_bridge")
@@ -182,6 +203,11 @@ func (c *Config) InstancesPlacementScriptlet() string {
 	return c.m.GetString("instances.placement.scriptlet")
 }
 
+// AuthorizationScriptlet returns the authorization scriptlet source code.
+func (c *Config) AuthorizationScriptlet() string {
+	return c.m.GetString("authorization.scriptlet")
+}
+
 // InstancesLXCFSPerInstance returns whether LXCFS should be run on a per-instance basis.
 func (c *Config) InstancesLXCFSPerInstance() bool {
 	return c.m.GetBool("instances.lxcfs.per_instance")
@@ -323,6 +349,14 @@ var ConfigSchema = config.Schema{
 	//  shortdesc: Agree to ACME terms of service
 	"acme.agree_tos": {Type: config.Bool, Default: "false"},
 
+	// gendoc:generate(entity=server, group=miscellaneous, key=authorization.scriptlet)
+	// When using scriptlet-based authorization, this option stores the scriptlet.
+	// ---
+	//  type: string
+	//  scope: global
+	//  shortdesc: Authorization scriptlet
+	"authorization.scriptlet": {Validator: validate.Optional(scriptletLoad.AuthorizationValidate)},
+
 	// gendoc:generate(entity=server, group=miscellaneous, key=backups.compression_algorithm)
 	// Possible values are `bzip2`, `gzip`, `lzma`, `xz`, or `none`.
 	// ---
@@ -390,6 +424,42 @@ var ConfigSchema = config.Schema{
 	//  shortdesc: Number of database stand-by members
 	"cluster.max_standby": {Type: config.Int64, Default: "2", Validator: maxStandByValidator},
 
+	// gendoc:generate(entity=server, group=cluster, key=cluster.rebalance.batch)
+	//
+	// ---
+	//  type: integer
+	//  scope: global
+	//  defaultdesc: `1`
+	//  shortdesc: Maximum number of instances to move during one re-balancing run
+	"cluster.rebalance.batch": {Type: config.Int64, Default: "1"},
+
+	// gendoc:generate(entity=server, group=cluster, key=cluster.rebalance.cooldown)
+	//
+	// ---
+	//  type: string
+	//  scope: global
+	//  defaultdesc: `6H`
+	//  shortdesc: Amount of time during which an instance will not be moved again
+	"cluster.rebalance.cooldown": {Type: config.String, Default: "6H", Validator: validate.Optional(expiryValidator)},
+
+	// gendoc:generate(entity=server, group=cluster, key=cluster.rebalance.interval)
+	//
+	// ---
+	//  type: integer
+	//  scope: global
+	//  defaultdesc: `0`
+	//  shortdesc: How often (in minutes) to consider re-balancing things. 0 to disable (default)
+	"cluster.rebalance.interval": {Type: config.Int64, Default: "0"},
+
+	// gendoc:generate(entity=server, group=cluster, key=cluster.rebalance.threshold)
+	//
+	// ---
+	//  type: integer
+	//  scope: global
+	//  defaultdesc: `20`
+	//  shortdesc: Percentage load difference between most and least busy server needed to trigger a migration
+	"cluster.rebalance.threshold": {Type: config.Int64, Default: "20", Validator: validate.Optional(rebalanceThresholdValidator)},
+
 	// gendoc:generate(entity=server, group=core, key=core.metrics_authentication)
 	//
 	// ---
@@ -844,3 +914,16 @@ func maxStandByValidator(value string) error {
 
 	return nil
 }
+
+func rebalanceThresholdValidator(value string) error {
+	n, err := strconv.Atoi(value)
+	if err != nil {
+		return fmt.Errorf("Value is not a number")
+	}
+
+	if n < 10 || n > 100 {
+		return fmt.Errorf("Value must be between 10 and 100")
+	}
+
+	return nil
+}
