@@ -9,9 +9,9 @@ import (
 	"net/http"
 	"time"
 
-	"github.com/lxc/incus/internal/server/db/query"
-	"github.com/lxc/incus/shared/api"
-	"github.com/lxc/incus/shared/logger"
+	"github.com/lxc/incus/v6/internal/server/db/query"
+	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/logger"
 )
 
 // InstanceBackup is a value object holding all db-related details about an instance backup.
