@@ -6,6 +6,6 @@ package db
 var Imports = []string{
 	"database/sql",
 	"fmt",
-	"github.com/lxc/incus/internal/server/db/query",
-	"github.com/lxc/incus/shared/api",
+	"github.com/lxc/incus/v6/internal/server/db/query",
+	"github.com/lxc/incus/v6/shared/api",
 }
