@@ -8,7 +8,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"github.com/lxc/incus/internal/server/db/generate/lex"
+	"github.com/lxc/incus/v6/internal/server/db/generate/lex"
 )
 
 func TestParse(t *testing.T) {
