@@ -11,10 +11,10 @@ import (
 	"slices"
 	"strings"
 
-	"github.com/lxc/incus/internal/server/db/cluster"
-	"github.com/lxc/incus/internal/server/db/query"
-	"github.com/lxc/incus/internal/version"
-	"github.com/lxc/incus/shared/api"
+	"github.com/lxc/incus/v6/internal/server/db/cluster"
+	"github.com/lxc/incus/v6/internal/server/db/query"
+	"github.com/lxc/incus/v6/internal/version"
+	"github.com/lxc/incus/v6/shared/api"
 )
 
 // GetNetworksLocalConfig returns a map associating each network name to its
@@ -292,7 +292,7 @@ WHERE networks.id = ? AND networks.state = ?
 }
 
 // CreatePendingNetwork creates a new pending network on the node with the given name.
-func (c *ClusterTx) CreatePendingNetwork(ctx context.Context, node string, projectName string, name string, netType NetworkType, conf map[string]string) error {
+func (c *ClusterTx) CreatePendingNetwork(ctx context.Context, node string, projectName string, name string, description string, netType NetworkType, conf map[string]string) error {
 	// First check if a network with the given name exists, and, if so, that it's in the pending state.
 	network := struct {
 		id      int64
@@ -325,7 +325,7 @@ func (c *ClusterTx) CreatePendingNetwork(ctx context.Context, node string, proje
 
 		// No existing network with the given name was found, let's create one.
 		columns := []string{"project_id", "name", "type", "description"}
-		values := []any{projectID, name, netType, ""}
+		values := []any{projectID, name, netType, description}
 		networkID, err = query.UpsertObject(c.tx, "networks", columns, values)
 		if err != nil {
 			return err
@@ -483,6 +483,42 @@ func (c *ClusterTx) GetNetworks(ctx context.Context, project string) ([]string,
 	return c.networks(ctx, project, "")
 }
 
+// GetNetworksAllProjects returns the names of all networks across all projects.
+func (c *ClusterTx) GetNetworksAllProjects(ctx context.Context) (map[string][]string, error) {
+	q := "SELECT projects.name, networks.name FROM networks JOIN projects ON networks.project_id=projects.id"
+
+	var projectName string
+	var networkName string
+	outfmt := []any{projectName, networkName}
+
+	result, err := queryScan(ctx, c, q, nil, outfmt)
+	if err != nil {
+		return nil, err
+	}
+
+	response := map[string][]string{}
+	for _, r := range result {
+		projectName, ok := r[0].(string)
+		if !ok {
+			continue
+		}
+
+		networkName, ok := r[1].(string)
+		if !ok {
+			continue
+		}
+
+		_, ok = response[projectName]
+		if !ok {
+			response[projectName] = []string{}
+		}
+
+		response[projectName] = append(response[projectName], networkName)
+	}
+
+	return response, nil
+}
+
 // Get all networks matching the given WHERE filter (if given).
 func (c *ClusterTx) networks(ctx context.Context, project string, where string, args ...any) ([]string, error) {
 	q := "SELECT name FROM networks WHERE project_id = (SELECT id FROM projects WHERE name = ?)"
