@@ -7,7 +7,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"github.com/lxc/incus/internal/server/db/node"
+	"github.com/lxc/incus/v6/internal/server/db/node"
 )
 
 func TestOpen(t *testing.T) {
