@@ -11,8 +11,8 @@ import (
 	"slices"
 	"strings"
 
-	"github.com/lxc/incus/internal/server/db/query"
-	"github.com/lxc/incus/shared/api"
+	"github.com/lxc/incus/v6/internal/server/db/query"
+	"github.com/lxc/incus/v6/shared/api"
 )
 
 // StorageRemoteDriverNames returns a list of remote storage driver names.
