@@ -1,8 +1,8 @@
 package drivers
 
 import (
-	"github.com/lxc/incus/internal/server/instance"
-	"github.com/lxc/incus/internal/server/instance/instancetype"
+	"github.com/lxc/incus/v6/internal/server/instance"
+	"github.com/lxc/incus/v6/internal/server/instance/instancetype"
 )
 
 // PrepareEqualTest modifies any unexported variables required for reflect.DeepEqual to complete safely.
