@@ -61,6 +61,7 @@ type VolumeSourceArgs struct {
 	Info               *Info
 	VolumeOnly         bool
 	ClusterMove        bool
+	StorageMove        bool
 }
 
 // VolumeTargetArgs represents the arguments needed to setup a volume migration sink.
@@ -73,11 +74,13 @@ type VolumeTargetArgs struct {
 	MigrationType         Type
 	TrackProgress         bool
 	Refresh               bool
+	RefreshExcludeOlder   bool
 	Live                  bool
 	VolumeSize            int64
 	ContentType           string
 	VolumeOnly            bool
 	ClusterMoveSourceName string
+	StoragePool           string
 }
 
 // TypesToHeader converts one or more Types to a MigrationHeader. It uses the first type argument
