@@ -4,6 +4,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"io/fs"
 	"net"
 	"net/http"
 	"os"
@@ -15,8 +16,7 @@ import (
 
 	"github.com/mdlayher/netx/eui64"
 
-	"github.com/lxc/incus/v6/client"
-	"github.com/lxc/incus/v6/internal/revert"
+	incus "github.com/lxc/incus/v6/client"
 	"github.com/lxc/incus/v6/internal/server/apparmor"
 	"github.com/lxc/incus/v6/internal/server/cluster"
 	"github.com/lxc/incus/v6/internal/server/cluster/request"
@@ -36,6 +36,7 @@ import (
 	"github.com/lxc/incus/v6/internal/version"
 	"github.com/lxc/incus/v6/shared/api"
 	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/revert"
 	"github.com/lxc/incus/v6/shared/subprocess"
 	"github.com/lxc/incus/v6/shared/util"
 	"github.com/lxc/incus/v6/shared/validate"
@@ -162,47 +163,10 @@ func (n *bridge) Validate(config map[string]string) error {
 		"bgp.ipv4.nexthop": validate.Optional(validate.IsNetworkAddressV4),
 		"bgp.ipv6.nexthop": validate.Optional(validate.IsNetworkAddressV6),
 
-		"bridge.driver": validate.Optional(validate.IsOneOf("native", "openvswitch")),
-		"bridge.external_interfaces": validate.Optional(func(value string) error {
-			for _, entry := range strings.Split(value, ",") {
-				entry = strings.TrimSpace(entry)
-
-				// Test for extended configuration of external interface.
-				entryParts := strings.Split(entry, "/")
-				if len(entryParts) == 3 {
-					// The first part is the interface name.
-					entry = strings.TrimSpace(entryParts[0])
-				}
-
-				err := validate.IsInterfaceName(entry)
-				if err != nil {
-					return fmt.Errorf("Invalid interface name %q: %w", entry, err)
-				}
-
-				if len(entryParts) == 3 {
-					// Check if the parent interface is valid.
-					parent := strings.TrimSpace(entryParts[1])
-					err := validate.IsInterfaceName(parent)
-					if err != nil {
-						return fmt.Errorf("Invalid interface name %q: %w", parent, err)
-					}
-
-					// Check if the VLAN ID is valid.
-					vlanID, err := strconv.Atoi(entryParts[2])
-					if err != nil {
-						return fmt.Errorf("Invalid VLAN ID %q: %w", entryParts[2], err)
-					}
-
-					if vlanID < 1 || vlanID > 4094 {
-						return fmt.Errorf("Invalid VLAN ID %q", entryParts[2])
-					}
-				}
-			}
-
-			return nil
-		}),
-		"bridge.hwaddr": validate.Optional(validate.IsNetworkMAC),
-		"bridge.mtu":    validate.Optional(validate.IsNetworkMTU),
+		"bridge.driver":              validate.Optional(validate.IsOneOf("native", "openvswitch")),
+		"bridge.external_interfaces": validate.Optional(validateExternalInterfaces),
+		"bridge.hwaddr":              validate.Optional(validate.IsNetworkMAC),
+		"bridge.mtu":                 validate.Optional(validate.IsNetworkMTU),
 
 		"ipv4.address": validate.Optional(func(value string) error {
 			if validate.IsOneOf("none", "auto")(value) == nil {
@@ -821,6 +785,13 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 			if err != nil {
 				return err
 			}
+
+			// Make sure the port is up.
+			link := &ip.Link{Name: entry}
+			err = link.SetUp()
+			if err != nil {
+				return fmt.Errorf("Failed to bring up the host interface %s: %w", entry, err)
+			}
 		}
 	}
 
@@ -1155,7 +1126,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 
 				// If IPv6 router acceptance is enabled (set to 1) then we now set it to 2.
 				err = localUtil.SysctlSet(fmt.Sprintf("net/ipv6/conf/%s/accept_ra", entry.Name()), "2")
-				if err != nil && !os.IsNotExist(err) {
+				if err != nil && !errors.Is(err, fs.ErrNotExist) {
 					return err
 				}
 			}
@@ -1163,7 +1134,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 			// Then set forwarding for all of them.
 			for _, entry := range entries {
 				err = localUtil.SysctlSet(fmt.Sprintf("net/ipv6/conf/%s/forwarding", entry.Name()), "1")
-				if err != nil && !os.IsNotExist(err) {
+				if err != nil && !errors.Is(err, fs.ErrNotExist) {
 					return err
 				}
 			}
