@@ -7,12 +7,13 @@ import (
 	"slices"
 	"strconv"
 
-	"github.com/lxc/incus/v6/internal/revert"
 	"github.com/lxc/incus/v6/internal/server/cluster/request"
 	"github.com/lxc/incus/v6/internal/server/db"
 	"github.com/lxc/incus/v6/internal/server/ip"
+	"github.com/lxc/incus/v6/internal/server/network/ovs"
 	"github.com/lxc/incus/v6/shared/api"
 	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/revert"
 	"github.com/lxc/incus/v6/shared/util"
 	"github.com/lxc/incus/v6/shared/validate"
 )
@@ -297,7 +298,7 @@ func (n *physical) Update(newNetwork api.NetworkPut, targetNode string, clientTy
 	// We only need to check in the database once, not on every clustered node.
 	if clientType == request.ClientTypeNormal {
 		if hostNameChanged {
-			isUsed, err := n.IsUsed()
+			isUsed, err := n.IsUsed(true)
 			if isUsed || err != nil {
 				return fmt.Errorf("Cannot update network parent interface when in use")
 			}
@@ -329,7 +330,7 @@ func (n *physical) Update(newNetwork api.NetworkPut, targetNode string, clientTy
 		_ = n.common.update(oldNetwork, targetNode, clientType)
 	})
 
-	// Apply changes to all nodes and databse.
+	// Apply changes to all nodes and database.
 	err = n.common.update(newNetwork, targetNode, clientType)
 	if err != nil {
 		return err
@@ -340,6 +341,24 @@ func (n *physical) Update(newNetwork api.NetworkPut, targetNode string, clientTy
 		return err
 	}
 
+	// Update OVS bridge entries (for dependent OVN networks).
+	if hostNameChanged {
+		vswitch, err := n.state.OVS()
+		if err == nil {
+			ovsBridge := fmt.Sprintf("incusovn%d", n.id)
+
+			err := vswitch.DeleteBridgePort(context.TODO(), ovsBridge, oldNetwork.Config["parent"])
+			if err != nil && err != ovs.ErrNotFound {
+				return err
+			}
+
+			err = vswitch.CreateBridgePort(context.TODO(), ovsBridge, newNetwork.Config["parent"], true)
+			if err != nil && err != ovs.ErrNotFound {
+				return err
+			}
+		}
+	}
+
 	revert.Success()
 
 	// Notify dependent networks (those using this network as their uplink) of the changes.
